@@ -1,7 +1,7 @@
 use std::cell::RefCell;
 use std::ops::Deref;
 use std::rc::Rc;
-use test::Bencher;
+use unit_test::Bencher;
 
 #[bench]
 fn parse_number_bench(bench: &mut Bencher) {
