@@ -2,12 +2,11 @@
 #[macro_use]
 extern crate strum;
 extern crate core;
-extern crate test;
+extern crate test as unit_test;
 
 #[cfg(test)]
 mod example;
-#[cfg(test)]
-mod unit_test;
-
 pub mod extend;
 pub mod new_less;
+#[cfg(test)]
+mod test;
