@@ -3,10 +3,10 @@ use crate::new_less::fileinfo::FileInfo;
 use crate::new_less::loc::Loc;
 use crate::new_less::node::StyleNode;
 use crate::new_less::rule::RuleNode;
-use serde::{Serialize};
+use serde::Serialize;
+use serde_json::{Map, Value};
 use std::fmt::{Debug, Formatter};
 use std::ops::Deref;
-use serde_json::{Map, Value};
 
 pub trait Comment {
   fn get_comment_blocknode(&self) -> Vec<CommentNode>;
@@ -43,24 +43,29 @@ impl CommentNode {
     if let Some(Value::String(content)) = map.get("content") {
       comment.content = content.to_string();
     } else {
-      return Err(format!("deserializer CommentNode has error -> content is empty"));
+      return Err(format!(
+        "deserializer CommentNode has error -> content is empty"
+      ));
     }
     if let Some(Value::Object(loc)) = map.get("loc") {
       comment.loc = Some(Loc::deserializer(loc));
     } else {
-      return Err(format!("deserializer CommentNode has error -> loc is empty"));
+      return Err(format!(
+        "deserializer CommentNode has error -> loc is empty"
+      ));
     }
     if let Some(Value::Number(startindex)) = map.get("startindex") {
       comment.startindex = startindex.to_string().parse::<usize>().unwrap();
     } else {
-      return Err(format!("deserializer CommentNode has error -> startindex is empty"));
+      return Err(format!(
+        "deserializer CommentNode has error -> startindex is empty"
+      ));
     }
 
     Ok(comment)
   }
 }
 
-
 impl Comment for FileInfo {
   fn get_comment_blocknode(&self) -> Vec<CommentNode> {
     get_comment_blocknode(&self.block_node)
