@@ -11,11 +11,11 @@ use crate::new_less::token::select::{
 };
 use crate::new_less::value::ValueNode;
 use crate::new_less::var::VarRuleNode;
+use serde::ser::SerializeStruct;
 use serde::{Deserialize, Serialize, Serializer};
+use serde_json::{Map, Value};
 use std::cmp::Ordering;
 use std::ops::Deref;
-use serde::ser::SerializeStruct;
-use serde_json::{Map, Value};
 
 #[derive(Debug, Clone, Serialize, PartialEq)]
 #[serde(tag = "type", content = "value")]
@@ -91,8 +91,8 @@ pub struct NewSelector {
 
 impl Serialize for NewSelector {
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
-    where
-      S: Serializer,
+  where
+    S: Serializer,
   {
     let mut state = serializer.serialize_struct("FileInfo", 3)?;
     state.serialize_field("loc", &self.loc)?;
@@ -124,52 +124,6 @@ impl NewSelector {
     obj
   }
 
-  ///
-  /// 反序列化
-  ///
-  pub fn deserializer(map: &Map<String, Value>, parent: NodeWeakRef, fileinfo: FileWeakRef) -> Result<Self, String> {
-    let mut select = Self {
-      paradigm_vec: vec![],
-      loc: None,
-      map: LocMap::new(&vec![]),
-      charlist: vec![],
-      parent,
-      fileinfo,
-    };
-    if let Some(Value::String(content)) = map.get("content") {
-      select.charlist = content.tocharlist();
-    } else {
-      return Err(format!("deserializer NewSelector has error -> charlist is empty!"));
-    }
-    if let Some(Value::Object(loc)) = map.get("loc") {
-      select.loc = Some(Loc::deserializer(loc));
-      select.map = LocMap::merge(select.loc.as_ref().unwrap(), &select.charlist).0;
-    } else {
-      select.map = LocMap::new(&select.charlist);
-    }
-    if let Some(Value::Array(charlist)) = map.get("paradigm_vec") {
-      for paradigm_vec in charlist {
-        let mut list = vec![];
-        if let Value::Array(paradigm) = paradigm_vec {
-          list = paradigm.iter().map(SelectParadigm::deserializer).collect();
-        }
-        if !list.is_empty() {
-          select.paradigm_vec.push(list);
-        }
-      }
-    } else {
-      return Err(format!("deserializer NewSelector has error -> paradigm_vec is empty!"));
-    }
-    Ok(select)
-  }
-
-  ///
-  /// 尽量减少调用次数
-  ///
-  pub fn value(&self) -> String {
-    self.charlist.poly()
-  }
-
   ///
   /// 向上查找 最近 select 节点 非 media
   ///
@@ -190,11 +144,66 @@ impl NewSelector {
     }
   }
 
+  ///
+  /// 反序列化
+  ///
+  pub fn deserializer(
+    map: &Map<String, Value>,
+    parent: NodeWeakRef,
+    fileinfo: FileWeakRef,
+  ) -> Result<Self, String> {
+    let mut select = Self {
+      paradigm_vec: vec![],
+      loc: None,
+      map: LocMap::new(&vec![]),
+      charlist: vec![],
+      parent,
+      fileinfo,
+    };
+    if let Some(Value::String(content)) = map.get("content") {
+      select.charlist = content.tocharlist();
+    } else {
+      return Err(format!(
+        "deserializer NewSelector has error -> charlist is empty!"
+      ));
+    }
+    if let Some(Value::Object(loc)) = map.get("loc") {
+      select.loc = Some(Loc::deserializer(loc));
+      select.map = LocMap::merge(select.loc.as_ref().unwrap(), &select.charlist).0;
+    } else {
+      select.map = LocMap::new(&select.charlist);
+    }
+    if let Some(Value::Array(charlist)) = map.get("paradigm_vec") {
+      for paradigm_vec in charlist {
+        let mut list = vec![];
+        if let Value::Array(paradigm) = paradigm_vec {
+          list = paradigm.iter().map(SelectParadigm::deserializer).collect();
+        }
+        if !list.is_empty() {
+          select.paradigm_vec.push(list);
+        }
+      }
+    } else {
+      return Err(format!(
+        "deserializer NewSelector has error -> paradigm_vec is empty!"
+      ));
+    }
+    Ok(select)
+  }
+
+  ///
+  /// 尽量减少调用次数
+  ///
+  pub fn value(&self) -> String {
+    self.charlist.poly()
+  }
+
   ///
   /// 生成当前 select 字符
   ///
-  pub fn code_gen(&self) -> Vec<String> {
-    let mut split_select_txt = vec![];
+  pub fn code_gen(&self) -> Result<Vec<Vec<SelectParadigm>>, String> {
+    let mut split_select_txt: Vec<Vec<SelectParadigm>> = vec![];
+
     for list in self.paradigm_vec.iter() {
       // 计算父 表达式
       let self_rule = self.parent.as_ref().unwrap().upgrade().unwrap();
@@ -204,45 +213,61 @@ impl NewSelector {
       if let Some(any_parent_rule) = select_rule_node {
         let heap_any_parent_rule = any_parent_rule.upgrade().unwrap();
         if let Some(SelectorNode::Select(ps)) =
-        heap_any_parent_rule.deref().borrow().selector.as_ref()
+          heap_any_parent_rule.deref().borrow().selector.as_ref()
         {
-          parent_select_txt = ps.code_gen()
+          parent_select_txt = ps.code_gen()?;
         };
       }
 
-      let mut txt = "".to_string();
+      // 清洗后 拼接自我结果
+      let mut self_list = vec![];
       let mut has_var = false;
 
       // 计算自己
-      list.iter().for_each(|par| match par {
-        SelectParadigm::SelectWrap(cc) => txt += cc,
-        SelectParadigm::CominaWrap(cc) => {
-          txt.push(cc.to_str());
-        }
-        SelectParadigm::VarWrap(_) => {
+      let mut var_index = -1;
+      for (np, p) in list.iter().enumerate() {
+        if matches!(p, SelectParadigm::VarWrap(..)) {
+          var_index = np as i32;
+        } else if matches!(p, SelectParadigm::KeyWrap(..)) {
           has_var = true;
-          for expr in parent_select_txt.iter() {
-            txt += expr;
-          }
         }
-        SelectParadigm::KeyWrap(keyword) => {
-          has_var = true;
-          txt = keyword.clone();
-        }
-      });
+      }
 
-      // 有 & 符号 则 不合 父 select 字符串做拼接
-      if has_var || parent_select_txt.is_empty() {
-        split_select_txt.push(txt)
+      if var_index > -1 {
+        has_var = true;
+
+        for expr in parent_select_txt.iter() {
+          let mut cplist = list.clone();
+          cplist.remove(var_index as usize);
+          for item in expr.iter().rev() {
+            cplist.insert(var_index as usize, item.clone())
+          }
+          self_list.push(cplist);
+        }
       } else {
-        for expr in parent_select_txt {
-          split_select_txt.push(format!("{} {}", expr, txt))
+        self_list.push(list.clone());
+      }
+
+      if has_var || parent_select_txt.is_empty() {
+        if !self_list.is_empty() {
+          split_select_txt.append(&mut self_list);
+        }
+      } else {
+        for expr in parent_select_txt.iter() {
+          for m in self_list.iter() {
+            let mut cp_expr = expr.clone();
+            if cp_expr.last() != Some(&SelectParadigm::CominaWrap(TokenCombinaChar::Space)) {
+              cp_expr.push(SelectParadigm::CominaWrap(TokenCombinaChar::Space));
+            }
+            cp_expr.append(&mut m.clone());
+            split_select_txt.push(cp_expr);
+          }
         }
       }
     }
 
     // 最终结果
-    split_select_txt
+    Ok(split_select_txt)
   }
 
   ///
@@ -290,7 +315,11 @@ impl NewSelector {
         {
           list.remove(0);
         }
-        list.push(obj);
+        if list.is_empty() && !matches!(obj, SelectParadigm::CominaWrap(TokenCombinaChar::Space))
+          || !list.is_empty()
+        {
+          list.push(obj);
+        }
       } else {
         let last_paradigm = list.last();
         if last_paradigm.is_some()
