@@ -8,8 +8,8 @@ use crate::new_less::scan::traversal;
 use crate::new_less::token::lib::Token;
 use serde::ser::SerializeStruct;
 use serde::{Serialize, Serializer};
-use std::fmt::{Debug, Formatter};
 use serde_json::{Map, Value};
+use std::fmt::{Debug, Formatter};
 
 #[derive(Clone)]
 pub struct ValueNode {
@@ -34,8 +34,8 @@ pub struct ValueNode {
 
 impl Serialize for ValueNode {
   fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
-    where
-      S: Serializer,
+  where
+    S: Serializer,
   {
     let mut state = serializer.serialize_struct("ValueNode", 2)?;
     state.serialize_field("content", &self.charlist.poly())?;
@@ -81,7 +81,11 @@ impl ValueNode {
   ///
   /// 反序列
   ///
-  pub fn deserializer(map: &Map<String, Value>, parent: NodeWeakRef, fileinfo: FileWeakRef) -> Result<Self, String> {
+  pub fn deserializer(
+    map: &Map<String, Value>,
+    parent: NodeWeakRef,
+    fileinfo: FileWeakRef,
+  ) -> Result<Self, String> {
     let mut obj = Self {
       charlist: vec![],
       parent,
@@ -93,7 +97,9 @@ impl ValueNode {
     if let Some(Value::String(content)) = map.get("content") {
       obj.charlist = content.tocharlist();
     } else {
-      return Err(format!("deserializer ValueNode has error -> content is empty!"));
+      return Err(format!(
+        "deserializer ValueNode has error -> content is empty!"
+      ));
     }
     if let Some(Value::Object(loc)) = map.get("loc") {
       obj.loc = Some(Loc::deserializer(loc));
@@ -102,9 +108,14 @@ impl ValueNode {
       obj.map = LocMap::new(&obj.charlist);
     }
     if let Some(Value::Array(array_value)) = map.get("ident") {
-      obj.word_ident_list = array_value.iter().map(IdentType::deserializer).collect::<Vec<IdentType>>()
+      obj.word_ident_list = array_value
+        .iter()
+        .map(IdentType::deserializer)
+        .collect::<Vec<IdentType>>()
     } else {
-      return Err(format!("deserializer ValueNode has error -> ident is empty!"));
+      return Err(format!(
+        "deserializer ValueNode has error -> ident is empty!"
+      ));
     }
     Ok(obj)
   }
@@ -532,7 +543,7 @@ impl ValueNode {
             if last_item.is_some()
               && last_item.unwrap().is_number()
               && (Self::is_number(Some(&next_char_no_space))
-              || Self::is_brackets(Some(&next_char_no_space)))
+                || Self::is_brackets(Some(&next_char_no_space)))
             {
               self
                 .word_ident_list
